<?php

namespace Teknisa\CADFIN\Controllers;

use Teknisa\CADFIN\Services\Ger08500ContaCorrenteService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\CADFIN\Controllers\TeknisaCrud;
use Doctrine\ORM\EntityManager;

class ContaCorrente extends TeknisaCrud{

    protected $dataSourceName = 'contcorr_cadastro';
    protected $dataSourceNameToSave = 'contcorr';
    protected $service;
    protected $entityManager;

    public function __construct($crudService, ParameterBag $parameterBag,  Ger08500ContaCorrenteService $service) {
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $dataSource = substr($request->getRoutePath(), 1, strlen($request->getRoutePath()));
        $this->dataSourceName = $dataSource;
        parent::find($request, $response);
    }
    
    public function recalcularValorUtilizado(DTO\Request $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->dataSourceName = "recalcular_valor_utiliado";
        $this->parameterBagColumns = array("CDREDUCONT");
        $condicaoAdicional = $this->retornaCondicao($row);
        $this->realizaConsulta($response,$condicaoAdicional);
        $this->dataSourceName = "contcorr_cadastro";
   	}
   	
   	public function realizaConsulta($response,$conditions) {
        $filterCriteria = new FilterCriteria($this->dataSourceName,$conditions);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
        $this->crudService->find(	$response,$newFilterCriteria);
    }
    
    public function retornaCondicao($row) {
        $conditions = array(
            array(
                "value" => $row['CDREDUCONT'],
                "operator" => "=",
                "columnName" => "CDREDUCONT"
            )
        );
        return $conditions;
    }

    public function validarContaCorrente(DTO\Request\Row $request, DTO\Response $response){
        try{
            $this->service->validarContaCorrente($request->getRow());
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function saveImplantacaoSaldo(DTO\Request\Row $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $this->service->implantaSaldoContaCorrente($row);
        }catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function excluiImplantacaoSaldo(DTO\Request\Row $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $this->service->excluiImplantacaoSaldo($row);
        }catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function evolucaoSaldo(DTO\Request $request, DTO\Response $response){
        try{
            $rows = $request->getDataSet()->getRows();
            $this->service->evolucaoSaldo($rows);
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function finalizarAlterarNossoNumero(DTO\Request $request, DTO\Response $response) {
        	
    	try {
    		$row = $request->getRow();
                
                $row['BOLETOCOMPLETO'] = $row['BOLETOCOMPLETO'] - 1;
                $row['BOLETOPREIMP'] = $row['BOLETOPREIMP'] - 1;
                

    		$this->service->finalizarAlterarNossoNumero($row);
         
		    $response->addDataSet(new DataSet('finalizarAlterarNossoNumero', ['success' => 'S']));
	    } catch (\Exception $e) {
		    $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
          }   
    } 
    
    public function gravaCertificado(DTO\Request $request, DTO\Response $response) {
        	
    	try {
    		$row = $request->getRow();
    		
    		$this->service->gravaCertificado($row);
         
		    $response->addDataSet(new DataSet('gravaCertificado', ['success' => 'S']));
	    } catch (\Exception $e) {
		    $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }   
    }     
    
}