module.exports = function(grunt){
  var backendModules = ['../backend/src/Teknisa'];
  var moduleName = 'cadFin';

  grunt.initConfig({
    buildEnvironment: {
      development: {
          configFile: "../backend/config/environment/devEnvironment.json"
      },
      production: {
          configFile: "../backend/config/environment/prodEnvironment.json"
      },
      test: {
          configFile: "../backend/config/environment/testEnvironment.json"
      },
      srcFolders: ["../backend/config/", "../backend/query/"]
    },
    zhIdGenerator: {
      options: {
        jsonPath: ['../'],
        menuPath: ["../menu.json"],
        replaceIds: false
      }
    },
  });

  function buildFileContent(srcFiles, filePath, directory) {
      var parts = filePath.split('/');
      parts.shift();
      parts.shift();
      parts.shift();
      parts.shift();
      var filename = parts[parts.length - 1];
      var extension = filename.split('.').pop().toUpperCase();
      if (extension == 'JSON' || extension == 'XML') {
          if (directory == 'datasources') {
              filename = parts.pop();
              filename = filename.replace(/\.[^/.]+$/, "");
              srcFiles[directory][filename] = './../src/Teknisa/' + parts.join('/');
          } else {
              srcFiles[directory].push('/src/Teknisa/' + parts.join('/'));
          }
      }
  }


  grunt.registerTask('backendStep', 'build backend config files', function () {
      var srcFiles = {config: [], datasources: {}},
      directories = ['config', 'datasources'];
      var dest = {
          config: '../backend/config/servicesMapping.json',
          datasources: '../backend/config/dataSourcesMapping.json'
      };
      directories.forEach(function (directory) {
          backendModules.forEach(function (module) {
              var subModules = grunt.file.expand({
                  filter: 'isDirectory'
              }, module +'/'+moduleName.toUpperCase()+'/Modules/*');

              subModules.forEach(function (subModule) {
                  grunt.file.expand({
                      filter: 'isFile'
                  }, subModule + '/' + directory + '/**/*').forEach(function (filePath) {
                      buildFileContent(srcFiles, filePath, directory);
                  });
              });
              
              grunt.file.expand({
                  filter: 'isFile'
              }, module + '/' + moduleName.toUpperCase() + '/' + directory + '/**/*').forEach(function (filePath) {
                  buildFileContent(srcFiles, filePath, directory);
              });
          });
      });

      grunt.file.write(dest.config, JSON.stringify(srcFiles.config, null, 2));
      grunt.file.write(dest.datasources, JSON.stringify(srcFiles.datasources, null, 2));
  });

  grunt.loadNpmTasks('grunt-zh-environment-builder');
  grunt.loadNpmTasks('grunt-zh-id-generator');

  grunt.registerTask('default', ['zhIdGenerator', 'backendStep']);
};
